Learn R Programming

data.tree (version 0.1.6)

Find: Find a Node by its path

Description

Find returns the Node at path .... The path is relative to the Node on which this method is called. Each argument provided corresponds to an element in the path, specified by the Node's name.

Usage

Find(...)

Arguments

...
the names of the nodes in the path

Value

  • the Node having path ..., or NULL if such a path does not exist

See Also

Node

Examples

Run this code
data(acme)
acme$Find('IT', 'Outsource')$name
#This is equivalent to:
acme$Find('IT')$Find('Outsource')$name
acme$Find('X', 'Y', 'Z')

Run the code above in your browser using DataLab