Learn R Programming

data.tree (version 0.1.6)

ball: Is Jack playing ball today?

Description

Ball contains daily weather conditions, and whether hypothetical Jack, a tennis player, played ball on a given day. We can use this data for classification trees, to check whether we can predict if Jack will play ball on a given day, given the current weather conditions. ball contains five factor attributes:

Usage

data(ball)

Arguments

format

data.frame

Details

  • outlook the weather outlook
  • temperature The temperature of the day (Hot, Mild, Cool, Cold)
  • humidity The humidity (High, Normal, Low)
  • wind The wind on the day (Weak, Strong)
  • play Whether Jack plays tennis on the given days (Yes, No)