Rdocumentation
powered by
Learn R Programming
data.tree (version 0.1.6)
PrintFixedDecimal: Format a Number as a Decimal
Description
Simple function that can be used as a format function when converting trees to a
data.frame
Usage
PrintFixedDecimal(x, digits = 3)
Arguments
x
a numeric scalar or vector
digits
the number of digits to print after the decimal point
Value
A string corresponding to x, suitable for printing