a field, method or function. The result of the attribute determines the
sorting. If it is a function, #' the attribute must take a Node as a first argument.
...
any parameters to be passed on the the attribute (in case it's a method or a
function)
decreasing
sort order
recursive
if TRUE, Sort will be called recursively on the Node's children.
This allows sorting an entire tree.